//
//  AdlantisIconNative
//  AdLantis SDK
//
//  Copyright 2014 Glossom, inc. All rights reserved.
//
//
#define USE_ADVIEW_IOS_NATIVE

using UnityEngine;
using System.Runtime.InteropServices;
using System;
using System.Collections;

namespace AdLantis.AdSdk
{
    public class AdlantisIconNative
    {
        [System.Serializable]
        public class Position
        {
          public float x;
          
          public float y;
          
          public Position(float x, float y)
          {
            this.x = x;
            this.y = y;
          }
        }

        [System.Serializable]
        public class IconAttr
        {
          public Position position;
          public bool showText;
          public Color textColor = Color.black;
        }

        public struct PointF
        {
          public float x;
      
          public float y;
      
          public PointF(float px, float py)
          {
            x = px;
            y = py;
          }
        }
        
        private static AdlantisIconNative instance;
        
        public static AdlantisIconNative Instance
        {
            get
            {
                if (instance == null)
                {
                  //TODO reaise Error
                }
                
                return instance;
            }
        }
        
        public static void initWithPublisherId(string publisherId , string callbackName )
        {
          #if UNITY_EDITOR
            instance = new AdlantisIconNative();
          #elif UNITY_IPHONE && USE_ADVIEW_IOS_NATIVE
            instance = new AdlantisIconNative();
          #elif UNITY_ANDROID
            instance = new AdlantisIconNativeAndroid(publisherId, callbackName);
          #endif
        } 
        
        public void Load(IconAttr[] icons)
        {
          foreach(IconAttr icon in icons)
          {
            Add(icon);
          }
          Load();
        }
        
        public virtual void Add(IconAttr icon)
        {
        }
        
        public virtual void Remove(IconAttr icon) 
        {
        }
        
        public virtual void Load()
        {
        }
        
        public virtual void Show()
        {

        }
        public virtual void Hide()
        {
          
        }
        
        public virtual void Log(string s)
        {
        }

    }
    
#if UNITY_ANDROID

  public class AdlantisIconNativeAndroid : AdlantisIconNative
  {
    private AndroidJavaClass AdlantisUnityBridgeClass =  new AndroidJavaClass("jp.adlantis.android.unity.IconUnityBridge");
    
    public static AndroidJavaObject getCurrentActivity() {
      AndroidJavaClass unityPlayer = new AndroidJavaClass("com.unity3d.player.UnityPlayer");
      AndroidJavaObject unityActivity = unityPlayer.GetStatic<AndroidJavaObject>("currentActivity");
      
      return unityActivity;
    }
      
    public AdlantisIconNativeAndroid(string publisherId, string callbackName)
    {
      AndroidJavaObject unityActivity = getCurrentActivity();
      AdlantisUnityBridgeClass.CallStatic("initialize", unityActivity, publisherId, callbackName);
    }
    
    static bool IsEmulator()
    {
      return Application.platform != RuntimePlatform.Android;
    }
    
    public override void Add(IconAttr icon)
    {
      AndroidJavaObject unityActivity = getCurrentActivity();
      AdlantisUnityBridgeClass.CallStatic("add", unityActivity, icon.position.x, icon.position.y, icon.showText,(int)(icon.textColor.r * 255), (int)(icon.textColor.g * 255), (int)(icon.textColor.b * 255));
    }

    public void setTextColor(IconAttr icon){
      AndroidJavaObject unityActivity = getCurrentActivity();
      AdlantisUnityBridgeClass.CallStatic("setTextColor", unityActivity, icon.position.x, icon.position.y, (int)(icon.textColor.r * 255), (int)(icon.textColor.g * 255), (int)(icon.textColor.b * 255));
    }
    public override void Remove(IconAttr icon)
    {
      AndroidJavaObject unityActivity = getCurrentActivity();
      AdlantisUnityBridgeClass.CallStatic("remove", unityActivity, icon.position.x, icon.position.y);
    }
    
    public override void Load()
    {
      AndroidJavaObject unityActivity = getCurrentActivity();
      AdlantisUnityBridgeClass.CallStatic("load", unityActivity);
    }

    public enum Visibility : int {
      VISIBLE = 0,
      INVISIBLE = 4,
      GONE = 8
    }
  
    public void SetVisibility(Visibility visibility)
    {
      AdlantisUnityBridgeClass.CallStatic("setViewVisibility", (int)visibility);
    }
    
    public override void Show()
    {
      SetVisibility(Visibility.VISIBLE);
    }
  
    public override void Hide()
    {
      SetVisibility(Visibility.INVISIBLE);
    }
  }

#endif

}
